import React from 'react';
import PropTypes from 'prop-types';
import {
  Switch,
  Route,
  routerRedux,
  Redirect,
} from 'dva/router';
import dynamic from 'dva/dynamic';
import { fulu as Flayout } from 'fl-pro';
import { ConfigProvider } from 'antd';
import zhCN from 'antd/es/locale/zh_CN';
const Api = configs.host.api;
const { ConnectedRouter } = routerRedux;

function RouteWithLayout({ layout, component, ...rest }) {
  return (
    <Route {...rest} render={(props) =>
      React.createElement(layout, props, React.createElement(component, props))
    } />
  );
}

const RouterWrapper = ({ history, app }) => {
  const GoodsList = dynamic({
    app,
    component: () => import('./views/Goods/GoodsList')
  });

  const GoodsEdit = dynamic({
    app,
    component: () => import('./views/Goods//GoodsEdit')
  });

  const PriceGroup = dynamic({
    app,
    component: () => import('./views/SecretPrice/PriceGroup')
  });

  const PriceMerchants = dynamic({
    app,
    component: () => import('./views/SecretPrice/PriceMerchants')
  });

  const PriceGoods = dynamic({
    app,
    component: () => import('./views/SecretPrice/PriceGoods')
  });

  const CommonTabs = dynamic({
    app,
    component: () => import('./views/SecretPrice/CommonTabs')
  });

  const PricePending = dynamic({
    app,
    component: () => import('./views/SecretPrice/PricePending')
  });

  const SupplyCommodity = dynamic({
    app,
    component: () => import('./components/SupplyCommodity/SupplyCommodity')
  });

  const OrderList = dynamic({
    app,
    models: () => [
      import('./models/order'),
    ],
    component: () => import('./components/Order/OrderList')
  });

  const MemberList = dynamic({
    app,
    models: () => [
      import('./models/order'),
      import ('./models/member')
    ],
    component: () => import('./components/Member/MemberList')
  });

  const TagmanageReport = dynamic({
    app,
    component: () => import('./views/Tagmanage/Report/TagmanageReport')
  });

  const ReportMerchants = dynamic({
    app,
    component: () => import('./views/Tagmanage/Report/ReportMerchants')
  });

  const TreasuryLocks = dynamic({
    app,
    component: () => import('./views/Tagmanage/Locks/TreasuryLocks')
  });

  const TreasuryLocksDetail = dynamic({
    app,
    component: () => import('./views/Tagmanage/Locks/TreasuryLocksDetail')
  });

  const InitiateLocks = dynamic({
    app,
    component: () => import('./views/Tagmanage/Locks/InitiateLocks')
  });

  const ActivityList = dynamic({
    app,
    component: () => import('./views/Tagmanage/activity/ActivityList')
  });

  const ActivityDetail = dynamic({
    app,
    component: () => import('./views/Tagmanage/activity/ActivityDetail')
  });

  const CardCommonTabs = dynamic({
    app,
    component: () => import('./views/Stock/Card/CommonTabs')
  });

  const GoodsDetail = dynamic({
    app,
    component: () => import('./views/Stock/Card/GoodsDetail')
  });

  const RechargeCommonTabs = dynamic({
    app,
    component: () => import('./views/Stock/Recharge/CommonTabs')
  });

  const RechargeGoodsDetail = dynamic({
    app,
    component: () => import('./views/Stock/Recharge/RechargeGoodsDetail')
  });

  const NoRight = dynamic({
    app,
    component: () => import('./components/NoRight')
  });
  
  const WraperRouter = (props, WrappedComponent) => {
    return (
      <Flayout initPath="/goodsList" openAllMenu={true} appName="福禄商户控制台" config={window.configs} {...props} >
        <ConfigProvider locale={zhCN}>
          <WrappedComponent {...props}/>
        </ConfigProvider>
      </Flayout>
    )
  }

  return (
    <ConnectedRouter history={history}>
        <Switch>
          <Route exact path='/' render={props => WraperRouter(props, GoodsList)} />
          <Route exact path='/member/memberList' render={props => WraperRouter(props, MemberList)} /> 
          <Route exact path='/order/orderList' render={props => WraperRouter(props, OrderList)} /> 
          <Route exact path='/goodsList' render={props => WraperRouter(props, GoodsList)} /> 
          <Route exact path='/goodsList/edit' render={props => WraperRouter(props, GoodsEdit)} /> 
          <Route exact path='/price/group' render={props => WraperRouter(props, PriceGroup)} /> 
          <Route exact path='/price/group/merchants' render={props => WraperRouter(props, PriceMerchants)} /> 
          <Route exact path='/price/group/goods' render={props => WraperRouter(props, PriceGoods)} /> 
          <Route exact path='/price/search' render={props => WraperRouter(props, CommonTabs)} /> 
          {/* <Route exact path='/price/pending' render={props => WraperRouter(props, PricePending)} />  */}
          <Route exact path='/stock/supplycommodity' render={props => WraperRouter(props, SupplyCommodity)} /> 
          <Route exact path='/tagmanage/report' render={props => WraperRouter(props, TagmanageReport)} /> 
          <Route exact path='/tagmanage/report/merchants' render={props => WraperRouter(props, ReportMerchants)} />
          <Route exact path='/tagmanage/treasury/locks' render={props => WraperRouter(props, TreasuryLocks)} />
          <Route exact path='/tagmanage/treasury/locks/detail' render={props => WraperRouter(props, TreasuryLocksDetail)} />
          <Route exact path='/tagmanage/treasury/locks/initiate' render={props => WraperRouter(props, InitiateLocks)} />
          <Route exact path='/tagmanage/activity' render={props => WraperRouter(props, ActivityList)} /> 
          <Route exact path='/tagmanage/activity/detail' render={props => WraperRouter(props, ActivityDetail)} />
          
          {/* 库存报备 */}
          {/* 卡密 */}
          <Route exact path='/stock/card' render={props => WraperRouter(props, CardCommonTabs)} />
          <Route exact path='/stock/card/goodsDetail' render={props => WraperRouter(props, GoodsDetail)} />
          {/* 直充 */}
          <Route exact path='/stock/recharge' render={props => WraperRouter(props, RechargeCommonTabs)} />
          <Route exact path='/stock/recharge/goodsDetail' render={props => WraperRouter(props, RechargeGoodsDetail)} />

          <Route exact path='/noRight' render={props => WraperRouter(props, NoRight)}/>
          {/* 403 */}
          <Route exact path="/403" render={props => WraperRouter(props, Flayout.Page403)} />
          {/* 404 */}
          <Route exact path="/404" render={props => WraperRouter(props, Flayout.Page404)} />
          {/* 500 */}
          <Route exact path="/500" render={props => WraperRouter(props, Flayout.Page500)} />
          {/* 网络错误 */}
          <Route exact path="/error" render={props => WraperRouter(props, Flayout.Page500)} />
          {/* 404 */}
          <Route render={props => WraperRouter(props, Flayout.Page404)} />
        </Switch>
    </ConnectedRouter>
  );
};

RouterWrapper.propTypes = {
  history: PropTypes.object,
  app: PropTypes.object,
};

RouterWrapper.defaultProps = {};

export default RouterWrapper;
