import React, { Component} from 'react';
import { connect } from 'dva';
import PropTypes from 'prop-types';
import {Spin,Modal} from 'antd';
import { Table } from 'fl-pro';
import './less/index.less';
import SearchForm from '../SearchForm';
class CommonModal extends Component {
    // 声明类型
    static propTypes = {
        width:PropTypes.number,
        title:PropTypes.string,
        url:PropTypes.string,
        rowKey:PropTypes.string,
        FormName: PropTypes.string,
        searchFun: PropTypes.func.isRequired,
        getFormData:PropTypes.func.isRequired,
        init: PropTypes.func,
        searchPagination: PropTypes.func,
        closeModal:PropTypes.func.isRequired,
        submitData:PropTypes.func.isRequired,
        
    }
    constructor(props) {
        super(props);
        this.state = {
            selectedRowKeys:[],
            selectData:[],
            postData:{
                PageIndex: 1,
                PageSize: 10,
            },
        }
    }

    componentDidMount(){
        if(this.props.params&&this.props.params.tableData&&this.props.params.tableData.checkList&&this.props.params.tableData.checkList.length>0){
            this.setState({
                selectedRowKeys:this.props.params.tableData.checkList.map((item)=>{
                    return item.memberId
                }),
                selectData:this.props.params.tableData.checkList
            })
        }
    }

    renderTable=(tableData)=>{
        const {selectedRowKeys,postData } = this.state;
        const pagination = {
            total:tableData.total?tableData.total:0,
            hideOnSinglePage: true,
            pageSize: postData.PageSize,
            current: postData.PageIndex,
            onShowSizeChange: (current, pageSize) => {
                postData.PageIndex=1;
                postData.PageSize=pageSize;
                Object.assign(postData, { PageSize: pageSize })
                this.setState({ postData }, () => {
                    this.props.searchPagination(postData);
                })
            },
            onChange: (current) => {
                postData.PageIndex=current;
                Object.assign(postData, { PageIndex: current })
                this.setState({ postData }, () => {
                    this.props.searchPagination(postData);
                })
               
            },
        };
        const rowSelection = {
            selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectData:selectedRows,
                    selectedRowKeys
                })
            },
            getCheckboxProps: record => ({
            //   disabled: record.name === 'Disabled User',
            //   name: record.name,
            }),
        };
        switch (tableData.type){
            case 0:
            return <Table 
                rowKey={tableData.rowKey}
                columns={tableData.columns}
                dataSource={tableData.dataResource?tableData.dataResource:[]}
                pagination={pagination}
                scroll={{y:420}}
            />
            case 1:
                return <Table 
                    rowSelection={{
                        type: "checkbox",
                        ...rowSelection,
                    }}
                    rowKey={tableData.rowKey}
                    columns={tableData.columns}
                    dataSource={tableData.dataResource?tableData.dataResource:[]}
                    pagination={pagination}
                    scroll={{y:420}}
                />

            case 2:
                return <Table 
                    rowSelection={{
                        type: "radio",
                        ...rowSelection,
                    }}
                    rowKey={tableData.rowKey}
                    columns={tableData.columns}
                    dataSource={tableData.dataResource?tableData.dataResource:[]}
                    pagination={pagination}
                    scroll={{y:420}}
                />   
        }
    }




    render() {
        const {loading} = this.props;
        const { width,title,okText,cancelText,FormName,tableData,url,zIndex } = this.props.params;
        const {selectData,selectedRowKeys } = this.state;
        return(
            <div>
                <Modal
                    className="CommonModal"
                    width={width?width+'px':'800px'}
                    zIndex={zIndex?zIndex:''}
                    title={title?title:"提示"}
                    okText={okText?okText:"确定"}
                    cancelText={cancelText?cancelText:"取消"}
                    visible={true}
                    destroyOnClose={true}
                    onCancel={
                        this.props.closeModal
                    }
                    onOk={
                        ()=>{
                            if(selectData&&this.props.submitData){
                                this.props.submitData(selectData,selectedRowKeys)
                            }
                        }
                    }
                >
                    {
                        FormName?<SearchForm 
                        name={FormName}
                        init={this.props.init}
                        search = {this.props.searchFun}
                        getFormData={this.props.getFormData}
                    />:''}
                    <Spin spinning={loading.effects[url]}>
                        {tableData&&tableData.columns&&this.renderTable(tableData)}
                    </Spin>
                </Modal>
            </div>
        )
    }
}

const mapStateToProps = (state) => {
	return {
		...state,
	};
}

export default connect(mapStateToProps)(CommonModal);


