import React from 'react';
import { connect } from 'dva';
import { Spin, Modal, Form, Input, message, Tag, Radio, Row, Col, Toast, Button } from "antd";
const FormItem = Form.Item;
const { confirm } = Modal;
import { Table } from 'fl-pro';
import moment from 'moment';
import './less/memberList.less';
import BreadCrumb from '../Breadcrumb';
import SearchForm from '../SearchForm';
import MemberDetail from './MemberDetail';
import statusToText from '../../utils/statusText';
import findIndex from 'lodash/findIndex';
class MemberList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      condition: [],
      postData: {
        pageIndex: 1,
        pageSize: 10,
      },
      total: 0,
      dataSource: [],
      detailData: {},
      visibleMemberDetail: false,
      appsList: []
    }
    this.columns = [
      {
        key: "1",
        title: '商户名称',
        align: 'left',
        dataIndex: "name",
        width: 150
      },
      {
        key: "2",
        title: '商户号',
        align: 'left',
        dataIndex: "memberCode",
        width: 90
      },
      {
        key: "3",
        title: '手机号',
        align: 'left',
        dataIndex: "tel",
        width: 150
      },
      {
        key: "4",
        title: '认证类型',
        align: 'left',
        dataIndex: "authenticationType",
        width: 80,
        render: text => {
          return statusToText.AuthenticationType[text];
        }
      },
      {
        key: "5",
        title: '认证主体名称',
        align: 'left',
        dataIndex: "authName",
        // width: 120
      },
      {
        key: "6",
        title: '认证状态',
        align: 'left',
        dataIndex: "authenticationStatus",
        width: 100,
        render: text => {
          return statusToText.AuthenticationStatus[text];
        }
      },
      {
        key: "7",
        title: '所属公司主体',
        align: 'left',
        dataIndex: "affiliatedCompanyName",
        // width: 75,
      },
      {
        key: "8",
        title: '利润中心',
        align: 'left',
        dataIndex: "profitCenterName",
        width: 120,
      },
      {
        key: "9",
        title: '结算类型',
        align: 'left',
        dataIndex: "transactionType",
        width: 100,
      },
      {
        key: "11",
        title: '商户类型',
        align: 'left',
        dataIndex: "memberType",
        width: 80,
        render: text => {
          return statusToText.MemberType[text];
        }
      },
      {
        key: "13",
        title: '协议类型',
        align: 'left',
        dataIndex: "isThird",
        width: 90,
        render: text => {
          return statusToText.IsThird[text];
        }
      },
      {
        key: "14",
        title: '注册时间',
        align: 'left',
        dataIndex: "registerDate",
        width: 170,
      },
      {
        key: "15",
        title: '认证时间',
        align: 'left',
        dataIndex: "innerAuditTime",
        width: 170,
      },
      {
        key: "16",
        title: '商户状态',
        align: 'left',
        dataIndex: "status",
        width: 75,
        render: text => {
          if(text == 1){
            return <i className="fa fa-check-circle-o" style={{color: '#21b847'}} data-toggle="tooltip" title="启用" aria-hidden="true"></i>
          }else{
            return <i className="fa fa-ban" style={{color:'#ea0000'}} data-toggle="tooltip" title="禁用" aria-hidden="true"></i>
          }
          
        }
      },
      {
        key: "17",
        dataIndex: "id",
        title: '操作',
        width: 80,
        fixed: 'right',
        align: 'center',
        render: (text, record) => (
          <div style={{color:"#4b9ae0"}}>
            {window.getAuthButtons().find(v => v.enCode === 'lr-detail') && <i className="iconfont" style={{cursor:'pointer',fontSize:'16px'}}
              title="查看详情"
              onClick={() => {
                this.setState({
                  visibleMemberDetail: true,
                  detailData: record
                })
              }}
            >&#xe611;</i>}
          </div>
        )
      }
    ];
  }
  // 初始化查询表单
  init = (values) => {
    this.setState({
      condition: values
    }, () => {
      this.getDataList()
    });
  }

  // 查询
  search = () => {
    const { postData, condition } = this.state;
    postData.pageIndex = 1
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getFormData = (params) => {
    this.setState({
      condition: params,
    })
  }

  // 分页查询
  searchPagination = () => {
    const { postData, condition } = this.state;
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getDataList = () => {
    let { postData, condition } = this.state;
    const _this = this;
    this.props.dispatch({
      type: 'member/GetMemberList',
      payload: {
        ...postData,
        ...condition
      }
    }).then(res => {
      if (res.code === '0') {
        _this.setState({
          dataSource: res.data.list,
          total: res.data.total
        })
      } else {
        message.error(res.message);
      }
    })
  }
  cancelModel = (data) => {
    this.setState({
      ...data,
      detailData: {}
    });
  }
  render() {
    const { total, postData, dataSource, detailData, visibleMemberDetail } = this.state;
    const breadcrumbList = [
      {
        name: "商户管理",
        href: ""
      },
      {
        name: "商户列表",
        href: ""
      }
    ];
    const pagination = {
      total,
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: postData.pageSize,
      current: postData.pageIndex,
      onShowSizeChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
      onChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
    };
    return (
      <div className="MemberList">
        <BreadCrumb paramsList={breadcrumbList} />
        <div className="MemberList-containter">
          <Spin spinning={!!(this.props.loading && this.props.loading.effects['member/GetMemberList'])} >
            <SearchForm 
              name="MemberList"
              init={this.init}
              search={this.search}
              getFormData={this.getFormData}
            />
            <Table
              hasUpdate={false}
              columns={this.columns}
              dataSource={dataSource||[]}
              pagination={pagination}
              bordered
              rowKey={record => JSON.stringify(record)}
              scroll={{ x: '1980px' }}
            />
          </Spin>
         {visibleMemberDetail && <MemberDetail getData={this.searchPagination} rowInfo={detailData} cancelModel={() => this.cancelModel({ visibleMemberDetail: false })} />}
        </div>
      </div>
    )
  }
}

export default connect(state => ({ ...state }))(Form.create()(MemberList));
