import React from 'react';
import { connect } from 'dva';
import {
  Spin, Form, Input, Modal, message, Divider, Tag, Descriptions, Button
} from 'antd';
import { Table }from 'fl-pro';
import './less/orderList.less';
import statusText from '../../utils/statusText';
class OrderDetail extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      detailData: {},
      dataSource: [],
      postData: {
        pageIndex: 1,
        pageSize: 10,
      },
      total: 0,
    }
    this.columns = [{
      key: "1",
      title: '订单编号',
      align: 'left',
      dataIndex: "subOrderId",
      width: 120
    },{
      key: "2",
      title: '供货商名称',
      align: 'left',
      dataIndex: "supplierName",
      width: 120
    },{
      key: "3",
      title: '供货商户编号',
      align: 'left',
      dataIndex: "supMemberCode",
      width: 110
    },{
      key: "4",
      title: '商品编号',
      align: 'left',
      dataIndex: "supProductId",
      width: 90
    },{
      key: "5",
      title: '商品名称',
      align: 'left',
      dataIndex: "supProductName",
    },{
      key: "6",
      title: '购买数量',
      align: 'left',
      dataIndex: "supBuyNum",
      width: 90
    },{
      key: "7",
      title: '面值',
      align: 'left',
      dataIndex: "supProductFaceValue",
      width: 90
    },{
      key: "8",
      title: '销售价',
      align: 'left',
      dataIndex: "supplierSalesPrice",
      width: 90
    },{
      key: "9",
      title: '状态',
      align: 'left',
      dataIndex: "supStatus",
      width: 85,
      render: text => {
        var supStatusObj = { 7: "已生成待推送", 11: "待配货", 21: "配货中", 31: "配货完成", 41: "充值成功", 51: "充值失败", 8: "风控拦截", 9: "推送失败" };
        return supStatusObj[text];
      }
    },{
      key: "10",
      title: '充值描述',
      align: 'left',
      dataIndex: "rechargeDescription",
      width: 90
    },{
      key: "11",
      title: '提交时间',
      align: 'left',
      dataIndex: "submitTime",
      width: 170
    },{
      key: "12",
      title: '完成时间',
      align: 'left',
      dataIndex: "finishTime",
      width: 170
    },{
      key: "13",
      title: '充值耗时',
      align: 'left',
      dataIndex: "diff",
      width: 90,
      render: text => {
        if(text){
          return  (text > 1 ? text : "1") + "秒";
        }else{
          return ''
        }
      }
    },]
  }
  componentWillMount = () => {
    this.getOrderDetail();
    this.getSubOrderDetails();
  }
  getOrderDetail = () => {
    const { rowInfo } = this.props
    this.props.dispatch({
      type: 'order/GetOrderDetail',
      payload: {
        orderId: rowInfo.orderId
      }
    }).then(res => {
      if (res.code === '0') {
        this.setState({
          detailData: res.data
        })
      } else {
        message.error(res.message);
      }
    })
  }
  //获取自订单列表
  getSubOrderDetails = () => {
    const { postData } = this.state;
    const { rowInfo } = this.props;
    this.props.dispatch({
      type: 'order/GetSubOrderDetails',
      payload: {
        orderId: rowInfo.orderId,
        ...postData
      }
    }).then(res => {
      if (res.code === '0') {
        this.setState({
          dataSource: res.data.list,
          total: res.data.total
        })
      } else {
        message.error(res.message);
      }
    })
  }
  handleClose = () => {
    this.props.cancelModel();
  }
  refresh = () => {
    this.getOrderDetail();
    this.setState({
      pageIndex: 1,
      pageSize: 10,},()=>{
      this.getSubOrderDetails();
    });
  }
  render() {
    const { detailData, dataSource, total, postData } = this.state;
    const pagination = {
      total,
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: postData.pageSize,
      current: postData.pageIndex,
      onShowSizeChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.getSubOrderDetails();
        })
      },
      onChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.getSubOrderDetails();
        })
      },
    };
    return (
      <Modal
        title='查看明细'
        visible
        width="1150px"
        onCancel={this.handleClose}
        maskClosable={false}
        footer={[
          <Button key="submit" type="primary" onClick={this.refresh}>
            刷新
          </Button>,
          <Button key="back" onClick={this.handleClose}>
            取消
          </Button>
        ]}
      >
      <Spin  spinning={!!this.props.loading.models.order}>
        <div style={{ maxHeight: '600px', padding: '10px 0', marginTop: '-15px', overflowY: 'scroll' }}>
          <Descriptions className="orderDetail" title="主订单明细" column={3} bordered={true} size={'small'}>
            <Descriptions.Item label="商户名称" span={1}>{detailData.memberName}</Descriptions.Item>
            <Descriptions.Item label="单价(元)" span={1}>{detailData.price}</Descriptions.Item>
            <Descriptions.Item label="订单编号" span={1}>{detailData.orderId}</Descriptions.Item>
            <Descriptions.Item label="外部订单号" span={1}>{detailData.customerOrderNo}</Descriptions.Item>
            <Descriptions.Item label="商品名称" span={1}>{detailData.productName}</Descriptions.Item>
            <Descriptions.Item label="库存类型" span={1}>{statusText.ProductType[detailData.productType]}</Descriptions.Item>
            <Descriptions.Item label="面值(元)" span={1}>{detailData.faceValue}</Descriptions.Item>
            <Descriptions.Item label="购买数量" span={1}>{detailData.buyNum}</Descriptions.Item>
            <Descriptions.Item label="充值账号" span={1}>{detailData.chargeAccount}</Descriptions.Item>
            <Descriptions.Item label="充值数额(元)" span={1}>{detailData.chargeValue}</Descriptions.Item>
            <Descriptions.Item label="充值游戏" span={1}>{detailData.chargeGameName}</Descriptions.Item>
            <Descriptions.Item label="充值大区" span={1}>{detailData.chargeGameRegion}</Descriptions.Item>
            <Descriptions.Item label="充值服务器" span={1}>{detailData.chargeGameSrv}</Descriptions.Item>
            <Descriptions.Item label="充值方式" span={1}>{detailData.chargeType}</Descriptions.Item>
            <Descriptions.Item label="收单时间" span={1}>{detailData.receiveTime}</Descriptions.Item>
            <Descriptions.Item label="入库时间" span={1}>{detailData.createTime}</Descriptions.Item>
            <Descriptions.Item label="完成时间" span={1}>{detailData.rechargeFinishTime}</Descriptions.Item>
            <Descriptions.Item label="付款Id" span={1}>{detailData.paymentId}</Descriptions.Item>
            <Descriptions.Item label="外部状态" span={1}>{statusText.OrderOuterStatus[detailData.orderOuterStatus]}</Descriptions.Item>
            <Descriptions.Item label="内部状态" span={1}>{statusText.OrderInnerStatus[detailData.orderInnerStatus]}</Descriptions.Item>
            <Descriptions.Item label="退款时间" span={1}>{detailData.refundTime}</Descriptions.Item>
            <Descriptions.Item label="退款金额(元)" span={1}>{detailData.refundAmount}</Descriptions.Item>
            <Descriptions.Item label="应用名称" span={1}>{detailData.appName}</Descriptions.Item>
            <Descriptions.Item label="售后状态" span={1}>{statusText.AfterSaleStatus[detailData.afterSaleStatus]}</Descriptions.Item>
            <Descriptions.Item label="批次号" span={1}>{detailData.batchNumber}</Descriptions.Item>
            <Descriptions.Item label="票据类型" span={1}>{statusText.InvoiceType[detailData.invoiceType]}</Descriptions.Item>
            <Descriptions.Item label="售后时间" span={1}>{detailData.afterSaleTime}</Descriptions.Item>
            <Descriptions.Item label="售后说明" span={1}>{detailData.afterSaleRemarks}</Descriptions.Item>
            <Descriptions.Item label="Ip" span={1}>{detailData.chargeIp}</Descriptions.Item>
            <Descriptions.Item label="运营商流水号" span={1}>{detailData.operatorSerialNumber}</Descriptions.Item>
            <Descriptions.Item label="内部描述" span={3}>{detailData.innerChargeDescription}</Descriptions.Item>
            <Descriptions.Item label="外部描述" span={3}>{detailData.rechargeDescription}</Descriptions.Item>
            <Descriptions.Item label="消息" span={3}>{detailData.errorMessage}</Descriptions.Item>
          </Descriptions>
          <Descriptions title="子订单明细" style={{ marginTop: '20px',marginBottom: '-20px' }}></Descriptions>
          <Table
            hasUpdate={false}
            columns={this.columns}
            dataSource={dataSource || []}
            pagination={pagination}
            bordered
            rowKey={record => JSON.stringify(record)}
            scroll={ {x: '1680px', y: '400px'}}
          />
        </div>
        </Spin>
      </Modal>
    );
  }
}
const mapStateToProps = (state) => {
  return {
    ...state,
  };
}
export default connect(mapStateToProps)(Form.create()(OrderDetail));

