import React from 'react';
import { connect } from 'dva';
import { Spin, Modal, Form, Input, message, Tag, Radio, Row, Col, Toast, Button } from "antd";
const FormItem = Form.Item;
const { confirm } = Modal;
import { Table } from 'fl-pro';
import moment from 'moment';
import './less/orderList.less';
import BreadCrumb from '../Breadcrumb';
import SearchForm from '../SearchForm';
import OrderDetail from './OrderDetail';
import statusToText from '../../utils/statusText';
import commonFun from '../../utils/utils';
import findIndex from 'lodash/findIndex';
class OrderList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      condition: [],
      postData: {
        pageIndex: 1,
        pageSize: 10,
      },
      total: 0,
      dataSource: [],
      detailData: {},
      visibleOrderDetail: false,
      appsList: []
    }
    this.columns = [
      {
        key: "1",
        title: '订单编号',
        align: 'left',
        dataIndex: "orderId",
        width: 180
      },
      {
        key: "2",
        title: '应用名称',
        align: 'left',
        dataIndex: "appName",
        width: 90
      },
      {
        key: "3",
        title: '批次号',
        align: 'left',
        dataIndex: "batchNumber",
        render: text => {
          return text || '/';
        }
      },
      {
        key: "4",
        title: '客户订单号',
        align: 'left',
        dataIndex: "customerOrderNo",
        width: 150
      },
      {
        key: "5",
        title: '充值帐号',
        align: 'left',
        dataIndex: "chargeAccount",
        width: 100
      },
      {
        key: "6",
        title: '订单类型',
        align: 'left',
        dataIndex: "orderType",
        width: 75,
        render: text => {
          const OrderTypeArr = ['', '话费', '流量', '卡密', '直充'];
          return OrderTypeArr[text];
        }
      },
      {
        key: "7",
        title: '支付方式',
        align: 'left',
        dataIndex: "paymentMethod",
        width: 75,
        render: text => {
          return statusToText.PaymentMethod[text];
        }
      },
      {
        key: "8",
        title: '订单状态',
        align: 'left',
        dataIndex: "orderOuterStatus",
        width: 80,
        render: text => {
          return statusToText.OrderOuterStatus[text];
        }
      },
      {
        key: "9",
        title: '入库时间',
        align: 'left',
        dataIndex: "createTime",
        width: 150,
      },
      {
        key: "10",
        title: '充值耗时',
        align: 'left',
        dataIndex: "diffTime",
        width: 80,
        render: (text,record) => {
          if(record.createTime && record.finishTime){
            let DiffTime = moment(record.finishTime).diff(moment(record.createTime), 'second');
            return (DiffTime > 1 ? DiffTime : "1") + "秒";
          }
        }
      },
      {
        key: "11",
        title: '售后',
        align: 'left',
        dataIndex: "afterSaleStatus",
        width: 80,
        render: text => {
          return statusToText.AfterSaleStatus[text];
        }
      },
      {
        key: "12",
        title: '进货商户名称',
        align: 'left',
        dataIndex: "memberName",
        width: 120,
      },
      {
        key: "13",
        title: '进货商户号',
        align: 'left',
        dataIndex: "memberCode",
        width: 90,
      },
      {
        key: "14",
        title: '平台商品编号',
        align: 'left',
        dataIndex: "productId",
        width: 110,
      },
      {
        key: "15",
        title: '平台商品名称',
        align: 'left',
        dataIndex: "productName",
      },
      {
        key: "16",
        title: '票据类型',
        align: 'left',
        dataIndex: "invoiceType",
        width: 75,
        render: text => {
          return statusToText.InvoiceType[text];
        }
      },
      {
        key: "17",
        title: '充值类型',
        align: 'left',
        width: 80,
        dataIndex: "chargeSpeed",
      },
      {
        key: "18",
        title: '单价(元)',
        align: 'left',
        dataIndex: "price",
        width: 100,
        render: text => {
          return text ? commonFun.toDecimal4(text) : '';
        }
      },
      {
        key: "20",
        title: '购买数量',
        align: 'left',
        dataIndex: "buyNum",
        width: 100,
        render : text => {
          return text > 0 ? text : '';
        }
      },
      {
        key: "21",
        title: '订单总金额',
        align: 'left',
        dataIndex: "orderTotalAmount",
        render: text => {
          return text ? commonFun.formatMoney(text) : '';
        }
      },
      {
        key: "24",
        title: 'FP收入',
        align: 'left',
        width: 100,
        dataIndex: "fpServiceFee",
        render: text => {
          return text ? commonFun.formatMoney(text) : '';
        }
      },
      {
        key: "25",
        title: 'FP进货单价(元)',
        align: 'left',
        width: 120,
        dataIndex: "supProductPrice",
        render: text => {
          return text ? commonFun.toDecimal4(text) : '';
        }
      },
      {
        key: "26",
        title: 'FP商品销售价',
        align: 'left',
        width: 110,
        dataIndex: "fpPrice",
        render: (text, record)=> {
          return commonFun.toDecimal4(text);
        }
      },
      {
        key: "27",
        title: 'FP进货数量',
        align: 'left',
        width: 100,
        dataIndex: "supBuyNum",
        render: text => {
          return text ? text : '';
        }
      },
      {
        key: "271",
        title: 'FP进货总额',
        align: 'left',
        width: 100,
        dataIndex: "orderPurchaseAmount",
        render: text => {
          return text ? commonFun.formatMoney(text) : '';
        }
      },
      {
        key: "28",
        title: '商品服务费率',
        align: 'left',
        dataIndex: "serviceTariffing",
        width: 110,
        render: text => {
          return (text || text === 0 || text === "0") ? (text * 100).toFixed(2) + '%' : ""
        }
      },
      {
        key: "29",
        title: '平台收入',
        align: 'left',
        dataIndex: "platformServiceFee",
        width: 100,
        render: text => {
          return text ? commonFun.formatMoney(text) : '';
        }
      },
      {
        key: "30",
        title: '供货商商品编号',
        align: 'left',
        dataIndex: "supProductId",
        width: 120
      },
      {
        key: "31",
        title: '供货商名称',
        align: 'left',
        dataIndex: "supMemberName",
        width: 100
      },
      {
        key: "32",
        title: '供货商商户号',
        align: 'left',
        width: 120,
        dataIndex: "supMemberCode",
      },
      {
        key: "33",
        title: '付款状态',
        align: 'left',
        dataIndex: "orderOuterStatus",
        width: 80,
        render: (text,record) => {
          if(record.orderOuterStatus != '61'){
            return record.paymentId ? '已付款': '未付款';
          }
        }
      },
      {
        key: "34",
        dataIndex: "id",
        title: '操作',
        width: 80,
        fixed: 'right',
        align: 'center',
        render: (text, record) => (
          <div>
            {window.getAuthButtons().find(v => v.enCode === 'lr-detail') && <i className="iconfont" style={{color:"#4b9ae0",cursor:'pointer',fontSize:'16px'}} 
              title="查看明细"
              onClick={() => {
                this.setState({
                  visibleOrderDetail: true,
                  detailData: record
                })
              }}
            >&#xe611;</i>}
          </div>
        )
      }
    ];
  }

  // componentWillMount(){
  //   this.GetAppsList();
  // }
  componentWillReceiveProps(nextProps) {
    const { GetAppsList } = nextProps.price;
    if (GetAppsList && GetAppsList !== this.props.price.GetAppsList) {
      if(GetAppsList.code==="0"){
          let appsList = [];
          if(GetAppsList.data.list && GetAppsList.data.list.length > 0){
            appsList = GetAppsList.data.list.map( item=>{
              return { 'name': item.appName,'value': item.id };
            });
          }
          this.setState({
              appsList: appsList
          })
      }else{
          message.destroy();
          message.warning(GetAppsList.message);
      }
    }
  }
  GetAppsList=()=>{
    this.props.dispatch({
        type: 'price/GetAppsList', 
        payload: {
            pageIndex:1,
            pageSize:9999,
            appType: 2,
            status: 2
        } 
    })
  }

  // 初始化查询表单
  init = (values) => {
    this.setState({
      condition: values
    }, () => {
      this.getDataList()
    });
  }

  // 查询
  search = () => {
    const { postData, condition } = this.state;
    postData.pageIndex = 1
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getFormData = (data) => {
    let { time, ...params} = data
    this.setState({
      condition: params,
    })
  }

  // 分页查询
  searchPagination = () => {
    const { postData, condition } = this.state;
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getDataList = () => {
    let { postData, condition } = this.state;
    const _this = this;
    this.props.dispatch({
      type: 'order/GetOrderList',
      payload: {
        ...postData,
        ...condition
      }
    }).then(res => {
      if (res.code === '0') {
        _this.setState({
          dataSource: res.data.list,
          total: res.data.total
        })
      } else {
        message.error(res.message);
      }
    })
  }
  cancelModel = (data) => {
    this.setState({
      ...data,
      detailData: {}
    });
  }
  render() {
    const { total, postData, dataSource, detailData, visibleOrderDetail, appsList } = this.state;
    const breadcrumbList = [
      {
        name: "订单管理",
        href: ""
      },
      {
        name: "订单列表",
        href: ""
      }
    ];
    const addSearch = [
      {
      name: '应用名称',
      index: 10,
      type: 7,
      id: 'clientId',
      placeholder: '请选择应用名称',
      items: [{ name: "应用名称", value: '' }, ...appsList]
    },]
    const pagination = {
      total,
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: postData.pageSize,
      current: postData.pageIndex,
      onShowSizeChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
      onChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
    };
    return (
      <div className="OrderList">
        <BreadCrumb paramsList={breadcrumbList} />
        <div className="OrderList-containter">
          
            <SearchForm 
              name="OrderList"
              // addData={addSearch}
              init={this.init}
              search={this.search}
              getFormData={this.getFormData}
            />
            <Spin spinning={!!this.props.loading.models.order} >
            <Table
              hasUpdate={false}
              columns={this.columns}
              dataSource={dataSource || []}
              pagination={pagination}
              bordered
              rowKey={record => JSON.stringify(record)}
              scroll={{ x: '3500px' }}
            />
            </Spin>
         {visibleOrderDetail && <OrderDetail getData={this.searchPagination} rowInfo={detailData} cancelModel={() => this.cancelModel({ visibleOrderDetail: false })} />}
        </div>
      </div>
    )
  }
}

export default connect(state => ({ ...state }))(Form.create()(OrderList));
