import React from 'react';
import PropTypes from 'prop-types';
import { Form, Input, Select, Col, Row, Button, Icon, DatePicker,AutoComplete,TreeSelect,message   } from 'antd';
import searchList from '../../configs/search';
import './less/searchForm.less';
import moment from 'moment';
import findIndex from 'lodash/findIndex';
import mathManage from '../../utils/mathManage';
const FormItem = Form.Item;
const { RangePicker } = DatePicker;
const { TreeNode } = TreeSelect;
import Rules from './rule'
class SearchForm extends React.PureComponent {
  // 声明类型
  static propTypes = {
    form: PropTypes.shape({
      validateFields: PropTypes.func.isRequired,
      getFieldDecorator: PropTypes.func.isRequired,
      setFieldsValue: PropTypes.func.isRequired,
      resetFields: PropTypes.func.isRequired,
      getFieldsValue: PropTypes.func.isRequired,
    }).isRequired,
    name: PropTypes.string.isRequired,
    search: PropTypes.func.isRequired,
    getFormData:PropTypes.func.isRequired,
    init: PropTypes.func,
    SetDataResource:PropTypes.func,
    addData:PropTypes.array,
    onRef:PropTypes.func,
  }

  constructor(props) {
    super(props);
    this.state = {
      screenWidth:1600,
      authButton:[],
      labelSpan:6,
      wrapperSpan:18,
    };
  }

  componentDidMount() {
    if(this.props.onRef){
      this.props.onRef(this);//父组件绑定子组件this
    }
    this.initValue()
    this.getAuthButton()
    this.setState({
      screenWidth:window.innerWidth
    });
    
    window.addEventListener('resize', this.handleResize.bind(this)) //监听窗口大小改变
  }

  componentWillReceiveProps(nextProps) {
    if(nextProps.isInitData!==this.props.isInitData){
      if(nextProps.isInitData){
        this.props.form.resetFields();
        this.props.init(this.props.form.getFieldsValue())
      }
    }
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.handleResize.bind(this)) ; // 移除监听
  }

  initValue=()=>{
    let obj = this.props.form.getFieldsValue();
    let orignData = {};
    let dataResource=[];   
    if(this.props.addData){
      dataResource=[...this.props.addData, ...searchList[this.props.name]]
    }else{
      dataResource=searchList[this.props.name]
    }
    if(obj&&Object.keys(obj).length>0){
      Object.keys(obj).map((k) => {
          if(obj[k]){
            Object.assign(orignData,{[k]:obj[k]})
          }
      })
      if(Object.keys(orignData).length>0){
        if(dataResource&&dataResource.length>0){
          dataResource.map((item) => {
            Object.keys(orignData).map((el) => {
              if(el==item.id){
                if(item.timeKey){
                  orignData[item.timeKey[0]]=orignData[el]&&orignData[el][0]? moment(orignData[el][0]).format('YYYY-MM-DD HH:mm:ss') : '';
                  orignData[item.timeKey[1]]=orignData[el]&&orignData[el][1]? moment(orignData[el][1]).format('YYYY-MM-DD HH:mm:ss') : '';
                  console.log(orignData)
                  delete orignData[el]
                }
              }
            })
          })
        }
      }
      this.props.init(orignData);
    } 
  }

  handleResize = e => {
    this.setState({
      screenWidth:window.innerWidth
    });
  }

  getAuthButton = () => {
    const authButton = window.getAuthButtons();
    this.setState({
      authButton
    })
  }

  search = () => {
    this.props.form.validateFields((err, values) => {
      if(!err){
        this.props.getFormData(values)
        this.props.search();
      }
    });
  }

  handleReset = () => {
    this.props.form.resetFields();
    this.initValue()
    sessionStorage.removeItem("FormValue")
  }

  selectSearch = (item,value)=>{
    this.props.SetDataResource({
      [item.id]:value
    })
  }

  initselectData= (item,e)=>{
    this.props.initselectData(item,e);
  }
  
  validFunction = (rule, value, callback) => {
    let arr = null;
    if(this.props.addData){
      arr=[...this.props.addData, ...searchList[this.props.name]]
    }else{
      arr=searchList[this.props.name]
    }
    const data= arr.find(el=>{
      return el.id === rule.field
    })
    //规则校验
    if(value && data && data.rules){
      let validResult = true;
      if(data.rules.ruleType == 'RegExp' && eval(Rules[data.rules.ruleName]) instanceof RegExp ){
        validResult = Rules[data.rules.ruleName].test(this.Trim(value));
      }else if(data.rules.ruleType == 'function' && typeof mathManage[data.rules.ruleName] === 'function'){
        validResult = mathManage[data.rules.ruleName](value);
      }
      //验证不通过
      if(!validResult){
        message.destroy();
        message.warning(data.rules.messgae?data.rules.messgae:data.name + "不符合规则")
        return ;
      }
    }
    callback();
  }


  Trim=(str)=>{
    return str.replace(/(^\s*)|(\s*$)/g, "");
  }

  renderViewComponent=(item)=>{
    const dateFormat = 'YYYY-MM-DD';
    switch(item.type){
      case 0:
      return <Input placeholder={item.placeholder} style={{...item.styles}} {...item.config}/>;
      break;
      case 1:
      return (<Select style={{...item.styles}} placeholder={item.placeholder} {...item.config}>
        {item.items ? item.items.map((opt) =>
          (<Select.Option value={opt.value} key={"se"+opt.value}>{opt.name}</Select.Option>)) : ''}
      </Select>);
      break;
      case 2:
      return  (<RangePicker
        style={{ width: '100%' }}
        format="YYYY-MM-DD HH:mm:ss"
        {...item.config}
        showTime={{ defaultValue: [moment('00:00:00', 'HH:mm:ss'), moment('23:59:59', 'HH:mm:ss')] }}
      />)
      break;
      case 3:
      return  (
        <DatePicker format={dateFormat} format="YYYY-MM-DD" {...item.config}/>
      )
      break;
      case 4:
      return  (
        <AutoComplete
          {...item.config}
          style={{...item.styles}}
          dataSource={item.items}
          defaultActiveFirstOption={true}
          filterOption={false}
          notFoundContent={"暂无数据"}
          placeholder={item.placeholder}
          onSearch={
            (e)=>{
              if(item.FunctionOj.setSelectData){
                let func=item.FunctionOj.setSelectData;
                func(item,e)
              }
            }
          }
          onFocus={(e)=>{
            if(item.FunctionOj.initFun){
              let initFun=item.FunctionOj.initFun(item,e);
              initFun(item,e)
            }
          }}
        />
      )
      break;
      case 5:
      return  (
        <Select
          {...item.config}
          style={{...item.styles}}
          showSearch
          defaultActiveFirstOption={true}
          filterOption={false}
          notFoundContent={"暂无数据"}
          labelInValue
          onSearch={
            (e)=>{this.selectSearch(item,e)}
          }
          onFocus={(e)=>{
            this.initselectData(item,e)
          }}
        >
        {item.items ? item.items.map((opt) =>
          (<Select.Option value={opt.value} key={"se"+opt.value}>{opt.name}</Select.Option>)) : ''}
        </Select>
      )
      break;
      case 6:
      return (
        <TreeSelect
          {...item.config}
          style={{...item.styles}}
          showSearch
          labelInValue
          treeData={item.items}
          dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
          placeholder="搜索"
          allowClear
          treeDefaultExpandAll
          onSearch={(e)=>{this.selectSearch(item,e)}}
        >
        </TreeSelect>
      )
      case 7:
      return (
        <Select 
          {...item.config}
          style={{...item.styles}} 
          placeholder={item.placeholder} 
          onSelect={
            (e)=>{
              if(item.FunctionOj.setSelectData){
                let func=item.FunctionOj.setSelectData;
                func(item,e)
              }
            }
          }
        >
          {item.items ? item.items.map((opt) => (
            <Select.Option value={opt.value} key={"se"+opt.value}>{opt.name}</Select.Option>
          )) : ''}
      </Select>);
      break;
      default:
      return null;
      break;
    }
  }
  render() {
    const {addData} = this.props;
    const {authButton,screenWidth} =this.state;
    const { getFieldDecorator } = this.props.form;
    let dataResource=[];   
    if(this.props.addData){
      dataResource=[...this.props.addData, ...searchList[this.props.name]]
    }else{
      dataResource=searchList[this.props.name]
    }
    dataResource&&dataResource.sort(function(a, b){return a.index - b.index});
    let formItemLayout = {
      labelCol: {
       span:6
      },
      wrapperCol: {
        span:18
      },
    };
    let maxformItemLayout = {
      labelCol: {
        span:6
       },
       wrapperCol: {
         span:18
       },
    }
    let minformItemLayout = {
      labelCol: {
        span:6
       },
       wrapperCol: {
         span:18
       },
    }
    if(screenWidth>=1800){
      formItemLayout.labelCol.span=5;
      formItemLayout.wrapperCol.span=19;
      maxformItemLayout.labelCol.span=7;
      maxformItemLayout.wrapperCol.span=17;
      minformItemLayout.labelCol.span=3;
      minformItemLayout.wrapperCol.span=21;
    }else if(screenWidth<1800&&screenWidth>=1400){
      formItemLayout.labelCol.span=7;
      formItemLayout.wrapperCol.span=17;
      maxformItemLayout.labelCol.span=9;
      maxformItemLayout.wrapperCol.span=15;
      minformItemLayout.labelCol.span=4;
      minformItemLayout.wrapperCol.span=20;
    }else if(screenWidth<1400){
      formItemLayout.labelCol.span=8;
      formItemLayout.wrapperCol.span=16;
      maxformItemLayout.labelCol.span=11;
      maxformItemLayout.wrapperCol.span=13;
      minformItemLayout.labelCol.span=6;
      minformItemLayout.wrapperCol.span=18;
    }
    return (
      <div className="search-box">
        <Form className="cxform" {...formItemLayout}>
          <Row className="searchRow" gutter={40}>
            {
              dataResource.map((item,i)=>{
                return <Col className="searchCol" span={item.showlength?item.showlength:6} key={'form'+item.id}>
                  <FormItem
                    className="FormItems"
                    label={item.name}
                    labelCol={
                      {span:item.formItems=="max"?maxformItemLayout.labelCol.span:(item.formItems=="min"?minformItemLayout.labelCol.span:formItemLayout.labelCol.span)}
                    }
                    wrapperCol={
                      {span:item.formItems=="max"?maxformItemLayout.wrapperCol.span:(item.formItems=="min"?minformItemLayout.wrapperCol.span:formItemLayout.wrapperCol.span)}
                    }
                  >
                    {getFieldDecorator(item.id, {
                      initialValue:item.defaultValue?item.defaultValue:'',
                      rules: [
                        {
                            validator: this.validFunction
                        }
                    ]
                    })(this.renderViewComponent(item))}
                  </FormItem>
                </Col>
              })
            }
            {/* <Col style={{ position: 'relative', top: '4px',float:'right',textAlign:'right' }}> */}
            <Col span={dataResource&&dataResource.length>3?6:(dataResource&&dataResource.length>0?24/(dataResource.length+1):12)} className="btnGroups">
              <Button type="primary" htmlType="submit" onClick={this.search}>查询</Button>
              <Button style={{ marginLeft: 8 }}   onClick={this.handleReset}>重置</Button>
              {
                this.props.addBtnData?(
                  this.props.addBtnData.enCode?((findIndex(authButton, { enCode:this.props.addBtnData.enCode }) !== -1) ?
                  <Button {...this.props.addBtnData.attributes} style={{...this.props.addBtnData.styles}}  onClick={this.props.addBtnData.handleEvents}>{this.props.addBtnData.name}</Button>:'')
                  : <Button {...this.props.addBtnData.attributes} style={{...this.props.addBtnData.styles}}  onClick={this.props.addBtnData.handleEvents}>{this.props.addBtnData.name}</Button>
                ):''
              }
            </Col>
          </Row>
        </Form>
      </div>
    );
  }
}

export default Form.create({
  onValuesChange(props, values,allValues) {
    let dataResource=[];   
    if(props.addData){
      dataResource=[...props.addData, ...searchList[props.name]]
    }else{
      dataResource=searchList[props.name]
    }
    if(allValues&&Object.keys(allValues).length>0){
      if(dataResource&&dataResource.length>0){
        dataResource.map((item) => {
          Object.keys(allValues).map((el) => {
            if(el==item.id){
              if(item.timeKey){
                allValues[item.timeKey[0]]=allValues[el]&&allValues[el][0]? moment(allValues[el][0]).format('YYYY-MM-DD HH:mm:ss') : '';
                allValues[item.timeKey[1]]=allValues[el]&&allValues[el][1]? moment(allValues[el][1]).format('YYYY-MM-DD HH:mm:ss') : '';
              }
            }
          })
        })
      }
    }
    for(var i in allValues){
      if(values){
        if( typeof values == 'string'||typeof values == 'number'){
          allValues[i]=values.replace(/(^\s*)|(\s*$)/g, "")
        }
      }
    }
    if(props.getFormData)  props.getFormData(allValues)
   
  }
})(SearchForm);
