import React from 'react';
import { connect } from 'dva';
import { Spin, Modal, Form, Input, message, Tag, Radio, Row, Col, Toast, Button } from "antd";
const FormItem = Form.Item;
const { confirm } = Modal;
import { Table } from 'fl-pro';
import './less/SupplyCommodity.less';
import BreadCrumb from '../Breadcrumb';
import SearchForm from '../SearchForm';
import SupplyProductList from './SupplyProductList';
import CommodityTags from './CommodityTags';
import CommodityPool from './CommodityPool';
import CopyToClipboard from 'react-copy-to-clipboard';
import statusToText from '../../utils/statusText';
import findIndex from 'lodash/findIndex';
class SupplyCommodity extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      condition: [],
      postData: {
        pageIndex: 1,
        pageSize: 10,
      },
      total: 0,
      dataSource: [],
      detailData: {},
      visibleSupplyProductList: false,
      visibleCommodityTags: false,
      visibleCommodityPool: false,
      SecondInvoiceTypeList: [],
      buttonClick: true
    }
    this.columns = [
      {
        key: "1",
        title: '商品编号',
        align: 'left',
        dataIndex: "supProductId",
        width: 90
      },
      {
        key: "2",
        title: '商户号',
        align: 'left',
        dataIndex: "memberCode",
        width: 90
      },
      {
        key: "3",
        title: '商品名称',
        align: 'left',
        dataIndex: "supProductName",
        // width: 200
      },
      {
        key: "4",
        title: '供货商名称',
        align: 'left',
        dataIndex: "supMemberName",
        width: 150
      },
      // {
      //   key: "5",
      //   title: '渠道名称',
      //   align: 'left',
      //   dataIndex: "sourceName",
      //   width: 100
      // },
      {
        key: "6",
        title: '商品类型',
        align: 'left',
        dataIndex: "supProductType",
        width: 75
      },
      {
        key: "7",
        title: '进货价(元)',
        align: 'left',
        dataIndex: "supProductPrice",
        width: 120,
        decimal: {
          length: 4, // 小数位保留长度
          round: true, // 是否四舍五入
        },
      },
      {
        key: "8",
        title: '面值(元)',
        align: 'left',
        dataIndex: "supProductFaceValue",
        width: 100,
        decimal: {
          length: 4, // 小数位保留长度
          round: true, // 是否四舍五入
        },
      },
      {
        key: "9",
        title: '库存状态',
        align: 'left',
        dataIndex: "supProductStockStatus",
        width: 80,
        render: text => {
          return statusToText.KmStockStatus[text];
        }
      },
      {
        key: "10",
        title: '销售状态',
        align: 'left',
        dataIndex: "supProductSaleStatus",
        width: 75,
        render: text => {
          return statusToText.KmSaleStatus[text];
        }
      },
      {
        key: "11",
        title: '票据类型',
        align: 'left',
        dataIndex: "invoiceType",
        width: 80,
        render: text => {
          return statusToText.InvoiceType[text];
        }
      },
      {
        key: "12",
        title: '二级票据类型',
        align: 'left',
        dataIndex: "secondInvoiceType",
        width: 120,
        render: (text, record) => {
          if(text || text == 0){
            if (text == 0) {
              return '无票'
            } else {
              return `${record.invoiceRate}${text == 1 ? '%普票' : (text == 2 ? '%专票' : '')}`
            }
          }
        }
      },
      {
        key: "13",
        title: '发布状态',
        align: 'left',
        dataIndex: "publish",
        width: 120,
        render: text => {
          return statusToText.KmPublish[text];
        }
      },
      {
        key: "14",
        title: '商户类型',
        align: 'left',
        dataIndex: "memberType",
        width: 75,
        render: text => {
          return statusToText.MemberType[text];
        }
      },
      {
        key: "15",
        title: '标签',
        align: 'left',
        dataIndex: "productTag",
        width: 200,
        render: (text, record) => {
          if (text && text.length > 0) {
            return <div>
              <Tag className="tagItem" key={JSON.stringify(text[0])} color={text[0].colorCode}
              >{text[0].tagName}</Tag>
              {text.length > 1 && <span className="more" onClick={() => {
                this.setState({
                  visibleCommodityTags: true,
                  detailData: record
                })
              }}>查看更多</span>}
            </div>
          } else {
            return ''
          }
        }
      },
      {
        key: "16",
        title: '商品详情',
        align: 'left',
        dataIndex: "supProductDescriptions",
        // ellipsis: true,
        render: text => {
          return <div className="detail">
            <span className="detail-container" title={text}>{text}</span>
            {text && <CopyToClipboard text={text}
              onCopy={() => message.success('复制成功')}>
              <span className="copy-detail">复制详情</span>
            </CopyToClipboard>}
          </div>
        }
      },
      {
        key: "17",
        dataIndex: "id",
        title: '操作',
        width: 100,
        fixed: 'right',
        align: 'center',
        render: (text, record) => (
          <div>
            <i tag="search" className="fa fa-plus-circle fa-lg operating-button"
              title="发布至商品池"
              onClick={() => {
                this.setState({
                  visibleCommodityPool: true,
                  detailData: record
                })
              }}
            ></i>
            <i tag="search" className="fa fa-lg fa-share operating-button"
              title="发布至平台商品"
              onClick={() => { this.handlePublish(record) }}
            ></i>
            {record.publish == 1 && <i tag="search" className="fa fa-lg fa-search operating-button"
              title="查看平台商品"
              onClick={() => {
                this.setState({
                  visibleSupplyProductList: true,
                  detailData: record
                })
              }}
            ></i>}
          </div>
        )
      }
    ];
  }

  // 初始化查询表单
  init = (values) => {
    this.setState({
      condition: values
    }, () => {
      this.getDataList()
    });
  }

  // 查询
  search = () => {
    const { postData, condition } = this.state;
    postData.pageIndex = 1
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getFormData = (params) => {
    let str = params.SecondInvoiceType
    params.SecondInvoiceType=str?str.split("-")[0]:str;
    params.InvoiceRate = str?str.split("-")[1]:'';
    this.setState({
      condition: params,
    })
  }

  // 分页查询
  searchPagination = () => {
    const { postData, condition } = this.state;
    this.setState({
      condition,
      postData
    }, () => {
      this.getDataList()
    });
  }

  getDataList = () => {
    const { postData, condition } = this.state;
    const _this = this;
    this.props.dispatch({
      type: 'stock/GetList',
      payload: {
        ...postData,
        ...condition
      }
    }).then(res => {
      if (res.code === '0') {
        _this.setState({
          dataSource: res.data.list,
          total: res.data.total
        })
      } else {
        message.error(res.message);
      }
    })
  }

  look = (record) => {
    this.props.history.push("/tagmanage/report/merchants?memberId=" + record.id)
    sessionStorage.setItem("reportMsg", JSON.stringify(record))
  }

  handlePublish = (record) => {
    const _this = this;
    confirm({
      title: '发布至平台商品',
      content: '确定直接将商品发布到平台商品里面？',
      okText: '确认',
      centered: true,
      cancelText: '取消',
      onOk() {
        //防止重复点击
        if(_this.state.buttonClick){
          _this.setState({buttonClick: false},()=>{
            _this.props.dispatch({
              type: 'stock/PublishSupProductToProduct', payload: {
                supProductType: record.supProductType,
                supProductId: record.supProductId,
              }
            }).then(res => {
              _this.setState({buttonClick: true})
              if (res.code == '0') {
                message.success('发布成功!');
                _this.getDataList();
              } else {
                return message.error(res.message);
              }
  
            });
          })
          
        }
      },
      onCancel() {
      },
    });
  }

  cancelModel = (data) => {
    this.setState({
      ...data,
      detailData: {}
    });
  }

  changeInvoiceType = (item,value) =>{
    if(item.id == 'InvoiceType'){
      if(value=='0'){
        this.setState({
            SecondInvoiceTypeList:[
                {
                    name:"0%普票",
                    value:"1"
                },
                {
                    name:"无票",
                    value:"0"
                }
            ]
        }) 
      }else if(value=="1"){
        this.setState({
            SecondInvoiceTypeList:[
                {
                    name:"3%普票",
                    value:"1-3"
                },
                {
                    name:"3%专票",
                    value:"2-3"
                },
                {
                    name:"6%普票",
                    value:"1-6"
                },
                {
                    name:"6%专票",
                    value:"2-6"
                },
                {
                    name:"10%普票",
                    value:"1-10"
                },
                {
                    name:"10%专票",
                    value:"2-10"
                },
                {
                    name:"13%普票",
                    value:"1-13"
                },
                {
                    name:"13%专票",
                    value:"2-13"
                },
                {
                    name:"16%普票",
                    value:"1-16"
                },
                {
                    name:"16%专票",
                    value:"2-16"
                },
            ]
        }) 
     } 
    }
  }

  render() {
    const { total, postData, dataSource, visibleSupplyProductList, detailData, visibleCommodityTags, visibleCommodityPool,SecondInvoiceTypeList } = this.state;
    const breadcrumbList = [
      {
        name: "供货商品管理",
        href: "#"
      }
    ];
    const addSearch = [{
      name: '票据类型',
      index: 9,
      type: 7,
      id: 'InvoiceType',
      placeholder: '请选择票据类型',
      items: [
        {name:'票据类型',value:''},
        { name: '寄售', value: 0 },
        { name: '自营', value: 1 },
      ],
      FunctionOj: {
        setSelectData: this.changeInvoiceType
      }
    },
    {
      name: '二级票据类型',
      index: 9,
      type: 7,
      id: 'SecondInvoiceType',
      placeholder: '请选择二级票据类型',
      formItems: "max",
      items: [{ name: "二级票据类型", value: '' }, ...SecondInvoiceTypeList],
      // FunctionOj: {
      //   setSelectData: this.getGoodsList
      // }
    },]
    
    const pagination = {
      total,
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: postData.pageSize,
      current: postData.pageIndex,
      onShowSizeChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
      onChange: (current, pageSize) => {
        this.setState({
          postData: {
            pageSize: pageSize,
            pageIndex: current
          }
        }, () => {
          this.searchPagination();
        })
      },
    };
    return (
      <div className="SupplyCommodity">
        <BreadCrumb paramsList={breadcrumbList} />
        <div className="SupplyCommodity-containter">
          <Spin spinning={!!(this.props.loading && this.props.loading.effects['stock/PublishSupProductToProduct'])} >
            <SearchForm 
              name="SupplyCommodity"
              addData={addSearch}
              init={this.init}
              search={this.search}
              getFormData={this.getFormData}
            />
            <Table
              hasUpdate={false}
              columns={this.columns}
              dataSource={dataSource || []}
              pagination={pagination}
              bordered
              rowKey="id"
              scroll={{ x: '1980px', y: window.innerHeight - 550 }}
            />
          </Spin>
        </div>
        {visibleCommodityPool && <CommodityPool getData={this.searchPagination} rowInfo={detailData} cancelModel={() => this.cancelModel({ visibleCommodityPool: false })} />}
        {visibleCommodityTags && <CommodityTags rowInfo={detailData} cancelModel={() => this.cancelModel({ visibleCommodityTags: false })} />}
        {visibleSupplyProductList && <SupplyProductList getData={this.searchPagination} rowInfo={detailData} cancelModel={() => this.cancelModel({ visibleSupplyProductList: false })} />}
      </div>
    )
  }
}

export default connect(state => ({ ...state }))(Form.create()(SupplyCommodity));
