import React from 'react';
import { connect } from 'dva';
import {
  Spin, Form, Input, Modal, message, Divider
} from 'antd';
import { Table } from 'fl-pro';
import statusToText from '../../utils/statusText';
class SupplyProductList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      total: 0,
      dataSource: [],
      postData: {
        pageIndex: 1,
        pageSize: 10
      },
    }
    this.columns = [
      {
        title: '库存组编号',
        dataIndex: 'groupCode',
        key: 'groupCode',
        width: '110px',
      }, {
        title: '库存组名称',
        dataIndex: 'groupName',
        key: 'groupName',
        width: '170px',
      }, {
        title: '商品编号',
        dataIndex: 'productId',
        key: 'productId',
        width: '110px',
      }, {
        title: '商品名称',
        dataIndex: 'productName',
        key: 'productName',
        // width: '170px',
      }, {
        title: '面值(元)',
        dataIndex: 'faceValue',
        key: 'faceValue',
        decimal: {
          length: 4, // 小数位保留长度
          round: true, // 是否四舍五入
        },
        width: '150px',
      }, {
        title: '票据类型',
        dataIndex: 'invoiceType',
        key: 'invoiceType',
        width: '90px',
        render: text => {
          return statusToText.InvoiceType[text];
        }
      }, {
        title: '销售状态',
        dataIndex: 'saleStatus',
        key: 'saleStatus',
        width: '100px',
        render: text => {
          return statusToText.KmSaleStatus[text];
        }
      }, {
        title: '库存状态',
        dataIndex: 'stockStatus',
        key: 'stockStatus',
        width: '100px',
        render: text => {
          return statusToText.StockStatus[text];
        }
      }]
  }

  componentWillMount() {
    this.getData();
  }
  //获取平台商品
  getData = () => {
    const { rowInfo } = this.props;
    this.props.dispatch({
      type: 'stock/GetGroupProductBySupProductId',
      payload: {
        ...this.state.postData,
        supProductType: rowInfo.supProductType,
        supId: rowInfo.supProductId
      }
    }).then(res => {
      if (res.code == '0') {
        this.setState({
          total: res.data.total,
          dataSource: res.data.list
        });
      } else {
        return message.error(res.message);
      }
    })
  }
  handleClose = () => {
    this.props.cancelModel();
  }
  render() {
    const { postData, total, dataSource } = this.state;
    const { rowInfo } = this.props;
    const pagination = {
      total,
      showSizeChanger: true,
      showQuickJumper: true,
      pageSize: postData.pageSize,
      current: postData.pageIndex,
      // pageSizeOptions: ['30', '50', '100'],
      onShowSizeChange: (current, pageSize) => {
        Object.assign(postData, { pageSize, pageIndex: current })
        this.setState({ postData }, () => {
          this.getData();
        });
      },
      onChange: (current) => {
        Object.assign(postData, { pageIndex: current });
        this.setState({ postData }, () => {
          this.getData();
        })
      },
    };
    return (
      <Modal
        title={rowInfo.supProductName || '查看平台商品'}
        visible
        width="1100px"
        onCancel={this.handleClose}
        maskClosable={false}
        footer={null}
      >
      <Spin spinning={!!(this.props.loading && this.props.loading.effects['stock/GetGroupProductBySupProductId'])} >
          <div className="card-pwd-stock-modal">
            <Table
              hasUpdate={false}
              columns={this.columns}
              dataSource={dataSource || []}
              pagination={pagination}
              // pagination={null}
              bordered
              rowKey={recode => JSON.stringify(recode)}
              scroll={{ y: 600 }}
            />
          </div>
        </Spin>
      </Modal>
    );
  }
}
const mapStateToProps = (state) => {
  return {
    ...state,
  };
}
export default connect(mapStateToProps)(Form.create()(SupplyProductList));

