import React, { Component } from 'react';
import { connect } from 'dva';
import {message,Form,Row,Col,Modal,Input} from 'antd';
import {WangEditor} from 'fl-pro' 
import './less/AddTreasury.less';
class AddTreasury extends Component {
    constructor(props) {
        super(props);
        this.state = {
            editorContent:''
        }
    }
    
    changeEditorContent=(data)=>{
        this.setState({
            editorContent:data
        })
    }
    

    submit=()=>{
        const { id,memberId } = this.props.addTreasuryData
        let postData={
            id,
            memberId,
            reMark:this.state.editorContent
        }
        this.props.form.validateFields((err, value) => {
            if(!err){
                this.props.dispatch({
                    type: 'stock/SupplementStockLockApply', 
                    payload: {
                        ...postData,
                        applyCount: value.applyCount,
                    } 
                });
            }
        });
    }

    renderProduct=(data)=>{
        if(data){
            if(data.productType==3){
                return "卡密"
            }else if(data.productType==4){
                return "直充"
            }else{
                return ''
            } 
        }
    }

    componentWillReceiveProps(nextProps){
        const {SupplementStockLockApply} = nextProps.stock;

        if (SupplementStockLockApply && SupplementStockLockApply !== this.props.stock.SupplementStockLockApply) {
            if(SupplementStockLockApply.code==="0"){
                message.destroy();
                message.success("补充成功")
                this.props.closeAddTreasury()
            }else{
                message.destroy();
                message.warning(SupplementStockLockApply.message);
            }
        }
    }

    validFunction = (rule, value, callback) => {
        let patter = /^[1-9]\d*$/;
        if(value){
            if(!patter.test(Number(value))){
                callback("请输入正整数");
                return;
            }else{
                if(value>50000){
                    callback("锁定数量不能超过50000");
                    return;
                }
            }
        }else{
            callback("请输入锁定数量");
            return;
        }
        callback();
    }


    render() {
        const {editorContent} = this.state
        const { getFieldDecorator } = this.props.form;
        const { addTreasuryData } =this.props
        const formItemLayout = {
            labelCol: {
              span:8
            },
            wrapperCol: {
              span:16
            },
        }
        const formItemLayout1 = {
            labelCol: {
              span:4
            },
            wrapperCol: {
              span:10
            },
        }
        return(
            <Modal
                className="AddTreasury"
                width="700px"
                title="提交补充审批"
                okText="确定"
                cancelText="取消"
                visible={true}
                onCancel={() =>{
                    this.props.closeAddTreasury();
                }}
                onOk={
                    this.submit
                }
                >
                <Row>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="商户编号">
                           <div>{addTreasuryData&&addTreasuryData.memberCode}</div>
                        </Form.Item>
                    </Col>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="商户名称">
                           <div>{addTreasuryData&&addTreasuryData.memberName}</div>
                        </Form.Item>
                    </Col>
                </Row>
                <Row>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="商品编号">
                           <div>{addTreasuryData&&addTreasuryData.productId}</div>
                        </Form.Item>
                    </Col>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="商品名称">
                           <div className="productName" title={addTreasuryData&&addTreasuryData.productName}>{addTreasuryData&&addTreasuryData.productName}</div>
                        </Form.Item>
                    </Col>
                </Row>
                <Row>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="供货商品编号">
                           <div>{addTreasuryData&&addTreasuryData.supProductId}</div>
                        </Form.Item>
                    </Col>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="供货商品名称">
                           <div className="productName" title={addTreasuryData&&addTreasuryData.productName}>{addTreasuryData&&addTreasuryData.supProductName}</div>
                        </Form.Item>
                    </Col>
                </Row>
                <Row>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="商品属性">
                           <div>{this.renderProduct(addTreasuryData)}</div>
                        </Form.Item>
                    </Col>
                    <Col  span={12}>
                        <Form.Item {...formItemLayout}  label="面值">
                           <div>{addTreasuryData&&addTreasuryData.faceValue}</div>
                        </Form.Item>
                    </Col>
                </Row>
                <Row >
                    <Col  span={24}>
                        <Form.Item {...formItemLayout1}  label="补充数量">
                            {getFieldDecorator('applyCount', {
                                initialValue:'',
                                rules: [
                                    {
                                        validator: this.validFunction
                                    }
                                ],
                            })(
                                <Input placeholder="请输入补充数量"/>
                            )}
                        </Form.Item>
                    </Col>
                </Row>
                <Row style={{marginTop:'10px'}}>
                    <Col span={24}>
                        <Form.Item {...formItemLayout1}  label="备注">
                            <WangEditor
                                width={500}
                                changeEditorContent={this.changeEditorContent}
                                editorContent={editorContent}
                                menus={[
                                    'head',  // 标题
                                    'bold',  // 粗体
                                    'fontSize',  // 字号
                                    'fontName',  // 字体
                                    'italic',  // 斜体
                                    'underline',  // 下划线
                                    'strikeThrough',  // 删除线
                                    'foreColor',  // 文字颜色
                                    'backColor',  // 背景颜色
                                    'link',  // 插入链接
                                    'list',  // 列表
                                    'justify',  // 对齐方式
                                    ]
                                }
                            />
                        </Form.Item>
                    </Col>
                </Row>
            </Modal>
        )
    }
}
export default connect(state => ({ ...state }))(Form.create()(AddTreasury));


