import React from 'react';
import { connect } from 'dva';
import {Spin,Form,message} from  "antd";
import { Table } from 'fl-pro';
import './less/ActivityList.less';
import BreadCrumb from '../../../../components/Breadcrumb';
import SearchForm from '../../../../components/SearchForm';
import findIndex from 'lodash/findIndex';
class ActivityList extends React.Component {
	constructor(props) {
        super(props);
        this.state={
            condition:[],
            postData:{
                PageIndex: 1,
                PageSize: 10,
            },
            total:0,
            activityList:[],
        }
	}

    // 初始化查询表单
    init = (values) => {
        this.setState({ 
            condition: values 
        },() => {
           this.GetActivityList()
        });
    }

    // 查询
    search = () => {
        const { postData,condition } = this.state;
        postData.PageIndex=1
        this.setState({ 
            condition,
            postData 
        },() => {
            this.GetActivityList()
        });
    }

    getFormData=(params)=>{
        this.setState({
          condition: params,
        })
    }

    // 分页查询
    searchPagination= ()=> {
        const { postData,condition } = this.state;
        this.setState({ 
            condition,
            postData 
        },() => {
            this.GetActivityList()
        });
    }

    //获取所有供货商户
    GetActivityList=()=>{
        const {postData,condition } =this.state;
        this.props.dispatch({
            type: 'activity/GetActivityList', 
            payload: {
                ...postData,
                ...condition
            } 
        });
    }

    look=(record)=>{
        this.props.history.push("/tagmanage/activity/detail?activityId="+record.activityId)
    }

	componentWillReceiveProps(nextProps) {
        const {GetActivityList} = nextProps.activity;
        // 获取所有供货商户
        if (GetActivityList && GetActivityList !== this.props.activity.GetActivityList) {
            if(GetActivityList.code==="0"){
              this.setState({
                activityList:GetActivityList.data.list,
                total:GetActivityList.data.total
              })
            }else{
                message.destroy();
                message.warning(GetActivityList.message);
            }
        }
        
    }

	render() {
        const {loading} = this.props;
        const {total,postData,activityList,} = this.state;
        const breadcrumbList = [
            {
                name:"运营管理",
                href:""
            },
            {
                name:"上游活动报名",
                href:""
            }
        ];
        let columns = [
            {
                key:"1",
                title: '活动编号',
                align: 'left',
                dataIndex:"activityId",
                fixed:"left",
                width:120
            },
            {
                key:"2",
                title: '活动发起方',
                align: 'left',
                dataIndex:"supMemberName",
                width:200
            },
            {
                key:"3",
                title: '活动名称',
                align: 'left',
                dataIndex:"activityName",
                width:400
            },
            {
                key:"4",
                title: '活动类型',
                align: 'left',
                dataIndex:"reduceType",
                render:(text)=>{
                    if(text==0){
                        return "折扣"
                    }else if(text==1){
                        return "立减"
                    }else{
                        return ''
                    }
                }
            },

            {
                key:"5",
                title: '活动开始时间',
                align: 'left',
                dataIndex:"beginTime",
                width:200
            },
            {
                key:"6",
                title: '活动结束时间',
                align: 'left',
                dataIndex:"endTime",
                width:200
            },
            {
                key:"7",
                title: '活动状态',
                align: 'left',
                dataIndex:"activityStatus",
                render:(text)=>{
                    if(text==0){
                        return "未开始"
                    }else if(text==1){
                        return "进行中"
                    }else if(text==2){
                        return "已结束"
                    }else if(text==3){
                        return "禁用"
                    }else{
                        return ''
                    }
                }
            },
            {
                key:"10",
                title: '官方活动',
                align: 'left',
                dataIndex:"isOfficial",
                render:(text)=>{
                    if(text==true){
                        return "官方"
                    }if(text==false){
                        return "非官方"
                    }else{
                        return ''
                    }
                }
            },
            {
                key:"11",
                title: '已通过/未通过',
                width:150,
                align: 'left',
                render:(text,record)=>{
                    if((!record.failCount&&record.failCount!=0)&&(!record.passCount&&record.passCount!=0)){
                        return ''
                    }
                    return record.passCount +'/'+ record.failCount*1
                }
            },
            {
                key:"12",
                title: '活动详情',
                width:100,
                align: 'center',
                fixed:"right",
                render:(text,record)=>(
                    <div style={{color:"#4b9ae0",cursor:'pointer'}}>
                        {(findIndex(window.getAuthButtons(), { enCode: 'lr_activity_detail' }) !== -1)?<i className="iconfont" style={{cursor:'pointer',fontSize:'16px'}}  onClick={()=>{this.look(record)}}  title="查看">&#xe611;</i>:''}
                    </div>
                )
            }
        ];
        const pagination = {
            total,
            hideOnSinglePage: false,
            pageSize: postData.PageSize,
            current: postData.PageIndex,
            onShowSizeChange: (current, pageSize) => {
                postData.PageIndex=1;
                postData.PageSize=pageSize;
                Object.assign(postData, { PageSize: pageSize })
                this.setState({ postData }, () => {
                    this.searchPagination();
                })
            },
            onChange: (current) => {
                postData.PageIndex=current; 
                Object.assign(postData, { PageIndex: current })
                this.setState({ postData }, () => {
                    this.searchPagination();
                })
            },
        };

		return (
			<div className="ActivityList">
                <BreadCrumb paramsList={breadcrumbList}/>
                <div className="ActivityList-containter">
                    <Spin spinning={loading.effects['activity/GetActivityList']}>
                        <SearchForm name="tagmanageActivity"
                            init={this.init} 
                            search={this.search} 
                            getFormData={this.getFormData} 
                        />
                        <Table 
                            columns={columns}
                            dataSource={activityList?activityList:[]}
                            pagination={pagination}
                            scroll={{y:window.innerHeight - 450,x:2000}}
                        />
                    </Spin>
                </div>
            </div>
		)
	}
}

export default connect(state => ({ ...state }))(Form.create()(ActivityList));